summaryrefslogtreecommitdiffstats
path: root/kppp/accounts.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kppp/accounts.cpp')
-rw-r--r--kppp/accounts.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kppp/accounts.cpp b/kppp/accounts.cpp
index 81e44459..740755e6 100644
--- a/kppp/accounts.cpp
+++ b/kppp/accounts.cpp
@@ -450,7 +450,7 @@ QueryReset::QueryReset(TQWidget *parent) : TQDialog(parent, 0, true) {
l1->activate();
// this activates the f-tqlayout and sets minimumSize()
f->show();
tl->addWidget(f);
@@ -466,7 +466,7 @@ QueryReset::QueryReset(TQWidget *parent) : TQDialog(parent, 0, true) {
connect(cancel, TQT_SIGNAL(clicked()),
this, TQT_SLOT(reject()));
- bbox->tqlayout();
+ bbox->layout();
tl->addWidget(bbox);
// TODO: activate if KGroupBox is fixed
@@ -450,7 +450,7 @@ QueryReset::QueryReset(TQWidget *parent) : TQDialog(parent, 0, true) {
l1->activate();
- // this activates the f-tqlayout and sets minimumSize()
+ // this activates the f-layout and sets minimumSize()
f->show();
tl->addWidget(f);